==> dl.php?src=linea21_1_4.zip: linea21/languages/fr/lang_workshoprep.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage fr
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['workshoprep']['section'] = "compte-rendu de groupes de travail";

/*	nommage des modules
 *  	*/
$lang['workshoprep']['name']='compte-rendu';
$lang['workshoprep']['confirm_add'] = "Ajout du compte-rendu réalisé avec succès\n";
$lang['workshoprep']['confirm_mod'] = "Modification du compte-rendu réalisée avec succès\n";
$lang['workshoprep']['confirm_sup'] ="Suppression du compte-rendu réalisée avec succès\n";


/*	nommage rubrique module
 *  	*/
$lang['workshoprep']['add']= 'Ajout d\'un '.$lang['workshoprep']['name'];
$lang['workshoprep']['mod']= 'Modification d\'un '.$lang['workshoprep']['name'];
$lang['workshoprep']['sup']= 'Suppression du '.$lang['workshoprep']['name'];
$lang['workshoprep']['det']= 'Détails du '.$lang['workshoprep']['name'];
$lang['workshoprep']['return_workshop']= 'Retour au groupe de travail';


/*	public
 *  	*/
$lang['workshoprep']['name2']='compte-rendu en détail';


/*	nommage rubrique add / mod /det
 *  	*/
$lang['workshoprep']['add_title']='Saisie des informations du nouveau '.$lang['workshoprep']['name'];
$lang['workshoprep']['mod_title']='Modification des informations du '.$lang['workshoprep']['name'];


/*	check integrité des données
 *  	*/
$lang['workshoprep']['no_title'] = 'Il est nécessaire de donner un titre au nouveau compte-rendu.';
$lang['workshoprep']['no_resume'] = 'Il est nécessaire d\'établir un resumé du compte-rendu.';


/*	nommage élément rubrique
 *  	*/
$lang['workshoprep']['title']='titre';
$lang['workshoprep']['resume']='résumé';
$lang['workshoprep']['workshop_product']='groupe de travail émetteur';

$lang['workshoprep']['statut']='état de publication';
$lang['workshoprep']['comment']='Commentaire';

$lang['workshoprep']['published_on']='date de publication';
$lang['workshoprep']['not_published']='non publié';

$lang['workshoprep']['generals']='Informations générales';
$lang['workshoprep']['parts']='Organisation du compte-rendu';
$lang['workshoprep']['link_res']='Liens associés au compte-rendu';
$lang['workshoprep']['biblio_res']='Ressources bibliographiques';


/*	nommage quickbox
 *  	*/
$lang['workshoprep']['qb_titleadd']=' derniers ajouts effectués';
$lang['workshoprep']['qb_titlemod']=' dernières modifications effectuées';
$lang['workshoprep']['qb_titlesup']=' dernières suppressions effectuées';
$lang['workshoprep']['qb_titlepubli']=' dernières publications effectuées';


/*	divers
 *  	*/
$lang['workshoprep']['description']='description';
$lang['workshoprep']['part_number']='partie ';


/*	messages
 *  	*/
$lang['workshoprep']['add_new_part']="Ajouter une nouvelle partie au compte-rendu courant";
$lang['workshoprep']['add_new_linkres']="Associer un nouveau lien au compte-rendu courant";
$lang['workshoprep']['add_new_bibliores']="Associer un nouvelle référence bibliographique au compte-rendu courant";

$lang['workshoprep']['no_link']="Aucun site n'est actuellement associé au compte-rendu";
$lang['workshoprep']['del_link']="Supprimer le lien";
$lang['workshoprep']['mod_link']="Modifier le lien";

$lang['workshoprep']['no_biblio']="Aucune référence bibliographique n'est actuellement associée au compte-rendu";
$lang['workshoprep']['del_biblio']="Supprimer la référence bibliographique";
$lang['workshoprep']['mod_biblio']="Modifier la référence bibliographique";

$lang['workshoprep']['no_part']="Actuellement, le compte-rendu ne contient aucune partie";
$lang['workshoprep']['del_part']="Supprimer la partie";
$lang['workshoprep']['mod_part']="Modifier la partie";






/*	rubrique d'aide

*  	*/
$lang['workshoprep']['help_add1']='Pour ajouter un compte-rendu, vous devez saisir  les informations requises dans le formulaire ci-dessus.';
$lang['workshoprep']['help_add2']='Après avoir validé le formulaire d\'ajout, vérifiez vos données dans le récapitulatif';
$lang['workshoprep']['help_add3']='Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur \'revoir les paramètres\' pour les modifier';

$lang['workshoprep']['help_mod1']='Vous pouvez modifier l\'ensemble des champs qui vous sont accessibles dans le formulaire ci-dessus';
$lang['workshoprep']['help_mod2']='Après avoir validé le formulaire de modification, vérifiez les informations saisies dans le récapitulatif';
$lang['workshoprep']['help_mod3']='Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur \'revoir les paramètres\' pour modifier à nouveau les données';


$lang['workshoprep']['help_det1']='Vous pouvez modifier les informations générales de ce compte-rendu en cliquant sur l\'icône de modification qui lui est associée';
$lang['workshoprep']['help_det2']='Vous pouvez supprimer ce compte-rendu en cliquant sur l\'icône de suppression qui lui est associée';
$lang['workshoprep']['help_det3']='Pour afficher les parties constituant le compte-rendu, les liens associés et ressources bibliographiques, cliquer sur afficher ces informations en bas de page';
$lang['workshoprep']['help_det4']='Pour Ajouter-Modifier-Supprimer les parties constituant le compte-rendu, les liens associés et ressources bibliographiques, cliquer sur les icônes qui leur sont associées';

$lang['workshoprep']['help_sup1']='Si vous ne souhaitez pas confirmer la suppression de ce compte-rendu, cliquer sur \'Annuler\'';


?>

==> dl.php?src=linea21_2_5_0.zip: linea21/languages/fr/lang_workshoprep.utf-8.php <==
<?php
/**
 * @package linea21\languages\fr
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['workshoprep']['section'] = "compte-rendu de groupes de travail";

/*	nommage des modules
 *  	*/
$lang['workshoprep']['name']='compte-rendu';
$lang['workshoprep']['confirm_add'] = "Ajout du compte-rendu réalisé avec succès\n";
$lang['workshoprep']['confirm_mod'] = "Modification du compte-rendu réalisée avec succès\n";
$lang['workshoprep']['confirm_sup'] ="Suppression du compte-rendu réalisée avec succès\n";


/*	nommage rubrique module
 *  	*/
$lang['workshoprep']['add']= 'Ajout d\'un '.$lang['workshoprep']['name'];
$lang['workshoprep']['mod']= 'Modification d\'un '.$lang['workshoprep']['name'];
$lang['workshoprep']['sup']= 'Suppression du '.$lang['workshoprep']['name'];
$lang['workshoprep']['det']= 'Détails du '.$lang['workshoprep']['name'];
$lang['workshoprep']['return_workshop']= 'Retour au groupe de travail';


/*	public
 *  	*/
$lang['workshoprep']['name2']='Sommaire';


/*	nommage rubrique add / mod /det
 *  	*/
$lang['workshoprep']['add_title']='Saisie des informations du nouveau '.$lang['workshoprep']['name'];
$lang['workshoprep']['mod_title']='Modification des informations du '.$lang['workshoprep']['name'];


/*	check integrité des données
 *  	*/
$lang['workshoprep']['no_title'] = 'Il est nécessaire de donner un titre au nouveau compte-rendu.';
$lang['workshoprep']['no_resume'] = 'Il est nécessaire d\'établir un resumé du compte-rendu.';


/*	nommage élément rubrique
 *  	*/
$lang['workshoprep']['title']='titre';
$lang['workshoprep']['resume']='résumé';
$lang['workshoprep']['workshop_product']='groupe de travail émetteur';

$lang['workshoprep']['statut']='état de publication';
$lang['workshoprep']['comment']='Commentaire';

$lang['workshoprep']['published_on']='date de publication';
$lang['workshoprep']['not_published']='non publié';

$lang['workshoprep']['generals']='Informations générales';
$lang['workshoprep']['parts']='Organisation du compte-rendu';
$lang['workshoprep']['link_res']='Liens associés';
$lang['workshoprep']['biblio_res']='Ressources bibliographiques';


/*	nommage quickbox
 *  	*/
$lang['workshoprep']['qb_titleadd']=' derniers ajouts effectués';
$lang['workshoprep']['qb_titlemod']=' dernières modifications effectuées';
$lang['workshoprep']['qb_titlesup']=' dernières suppressions effectuées';
$lang['workshoprep']['qb_titlepubli']=' dernières publications effectuées';


/*	divers
 *  	*/
$lang['workshoprep']['description']='description';
$lang['workshoprep']['part_number']='partie ';


/*	messages
 *  	*/
$lang['workshoprep']['add_new_part']="Ajouter une nouvelle partie au compte-rendu courant";
$lang['workshoprep']['add_new_linkres']="Associer un nouveau lien au compte-rendu courant";
$lang['workshoprep']['add_new_bibliores']="Associer un nouvelle référence bibliographique au compte-rendu courant";

$lang['workshoprep']['no_link']="Aucun site n'est actuellement associé au compte-rendu";
$lang['workshoprep']['del_link']="Supprimer le lien";
$lang['workshoprep']['mod_link']="Modifier le lien";

$lang['workshoprep']['no_biblio']="Aucune référence bibliographique n'est actuellement associée au compte-rendu";
$lang['workshoprep']['del_biblio']="Supprimer la référence bibliographique";
$lang['workshoprep']['mod_biblio']="Modifier la référence bibliographique";

$lang['workshoprep']['no_part']="Actuellement, le compte-rendu ne contient aucune partie";
$lang['workshoprep']['del_part']="Supprimer la partie";
$lang['workshoprep']['mod_part']="Modifier la partie";






/*	rubrique d'aide

*  	*/
$lang['workshoprep']['help_add1']='Pour ajouter un compte-rendu, vous devez saisir  les informations requises dans le formulaire ci-dessus.';
$lang['workshoprep']['help_add2']='Après avoir validé le formulaire d\'ajout, vérifiez vos données dans le récapitulatif';
$lang['workshoprep']['help_add3']='Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur \'revoir les paramètres\' pour les modifier';

$lang['workshoprep']['help_mod1']='Vous pouvez modifier l\'ensemble des champs qui vous sont accessibles dans le formulaire ci-dessus';
$lang['workshoprep']['help_mod2']='Après avoir validé le formulaire de modification, vérifiez les informations saisies dans le récapitulatif';
$lang['workshoprep']['help_mod3']='Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur \'revoir les paramètres\' pour modifier à nouveau les données';


$lang['workshoprep']['help_det1']='Vous pouvez modifier les informations générales de ce compte-rendu en cliquant sur l\'icône de modification qui lui est associée';
$lang['workshoprep']['help_det2']='Vous pouvez supprimer ce compte-rendu en cliquant sur l\'icône de suppression qui lui est associée';
$lang['workshoprep']['help_det3']='Pour afficher les parties constituant le compte-rendu, les liens associés et ressources bibliographiques, cliquer sur afficher ces informations en bas de page';
$lang['workshoprep']['help_det4']='Pour Ajouter-Modifier-Supprimer les parties constituant le compte-rendu, les liens associés et ressources bibliographiques, cliquer sur les icônes qui leur sont associées';

$lang['workshoprep']['help_sup1']='Si vous ne souhaitez pas confirmer la suppression de ce compte-rendu, cliquer sur \'Annuler\'';


?>
